import AddressList from "@/components/AddressList";
import Popup from "@/components/popup";
import { Text, View } from "@tarojs/components"
import classnames from "classnames";
import { memo, useCallback, useEffect, useMemo, useState } from "react";
import styles  from './index.module.scss'


type Param =  {
    onSelect?: (val:any) => void
}

export default memo(({onSelect}: Param) => {
    const [showAddressList, setShowAddressList] = useState(false)

    //选择地址
    const [userInfo, setUserInfo] = useState<any>()
    const getAddress = useCallback((val) => {
        setShowAddressList(false)
        setUserInfo(val)
        onSelect?.(val)
    }, [])

    //地址格式
    const formatAddress = useMemo(() => {
        if(userInfo) {
            return userInfo.province_name + userInfo.city_name + userInfo.district_name + userInfo.address_detail
        }
    }, [userInfo])
    return (
        <View>
            <View className={styles.order_address} onClick={() => setShowAddressList(true)}>
                <View className={classnames(styles.order_address_icon, 'iconfont icon-daohang')}></View>
                {!userInfo&&<View className={styles.order_address_text_no}>请选择收货地址及信息</View>||
                <View className={styles.order_address_text_con}>
                    <View className={styles.order_address_text_title}>{formatAddress}</View>
                    <View className={styles.order_address_text_name}>
                        <Text>{userInfo?.name}</Text>
                        <Text>{userInfo?.phone}</Text>
                    </View>
                </View>}
                <View className={classnames(styles.order_address_more_icon, 'iconfont icon-a-moreback')}></View>
            </View>
            <Popup show={showAddressList} showTitle={false} onClose={() => setShowAddressList(false)}>
                <View className={styles.order_address_list}>
                    <View className={styles.order_address_title}>请选择收货地址</View>
                    <AddressList onSelect={(item) => getAddress(item)}/>
                </View>
            </Popup>
        </View>
    )
})