import { SaleOrderPreViewApi } from "@/api/order";
import { formatPriceDiv } from "@/common/fotmat";
import Popup from "@/components/popup";
import SearchInput from "@/components/searchInput";
import { Text, Textarea, View } from "@tarojs/components"
import Taro, { useRouter } from "@tarojs/taro";
import classnames from "classnames";
import { useCallback, useEffect, useMemo, useRef, useState } from "react";
import AddressInfo from "./components/addressInfo";
import EstimatedAmount from "./components/estimatedAmount";
import KindList from "./components/kindList";
import OrderState from "./components/orderState";
import Remark from "./components/remark";
import styles  from './index.module.scss'
 
 export default () => {
    const [showDesc, setShowDesc] = useState(false)
    
    //获取购物车传过来的id
    type orderPreParam = {shopping_cart_product_color_list:{shopping_cart_product_color_id:number}[], sale_mode:number}
    const router = useRouter()
    const idsAndSaleModel = useRef<orderPreParam>({shopping_cart_product_color_list:[], sale_mode:0})
    useEffect(() => {
        idsAndSaleModel.current.sale_mode =  Number(router.params.sale_mode)
        router.params.ids?.split('-')?.map(item => {
            return idsAndSaleModel.current.shopping_cart_product_color_list?.push({
                shopping_cart_product_color_id: Number(item)
            })
        })
        getSaleOrderPreView()
    }, [])

    //获取销售预览订单
    type preViewOrderParam = {estimate_amount:number, estimate_weight:number, product_color_list:any[], sale_mode:number, sale_mode_name:string}
    const [preViewOrder, setPreViewOrder] = useState<preViewOrderParam>() //获取到的原始数据
    const {fetchData} = SaleOrderPreViewApi()
    const getSaleOrderPreView = async () => {
        if(idsAndSaleModel.current.shopping_cart_product_color_list?.length > 0) {
            let res = await fetchData(idsAndSaleModel.current)
            setPreViewOrder(res.data)
        }       
    }

    //监听获取到的数据
    useEffect(() => {
        if(preViewOrder)
            formatData()
    }, [preViewOrder])

    //格式化数据格式
    const [formatPreViewOrder, setFormatPreViewOrder] = useState<any>() //格式化后的数据
    const formatData = () => {  
        if(preViewOrder?.product_color_list&&preViewOrder?.product_color_list.length > 0) {
            let dataList = {}
            let num_count = 0 //总数量
            preViewOrder?.product_color_list.map(item => {
                dataList[item.product_code] =  dataList[item.product_code]||{}
                dataList[item.product_code].product_code = item.product_code
                dataList[item.product_code].product_name = item.product_name
                dataList[item.product_code].sale_mode_name = preViewOrder.sale_mode_name
                dataList[item.product_code].color_list =  dataList[item.product_code]?.color_list||[]
                dataList[item.product_code].color_list.push(item)
                //大货
                if (preViewOrder.sale_mode == 0) num_count += item.roll
                //剪板或散件
                if (preViewOrder.sale_mode == 1 || preViewOrder.sale_mode == 2) num_count += item.length
            })
            if (preViewOrder.sale_mode == 1 || preViewOrder.sale_mode == 2) num_count = Number(num_count / 100);
            setFormatPreViewOrder({
                estimate_amount: preViewOrder.estimate_amount, //预估金额
                estimate_weight: preViewOrder.estimate_weight,
                sale_mode: preViewOrder.sale_mode,
                sale_mode_name: preViewOrder.sale_mode_name, 
                colo_count: preViewOrder.product_color_list.length, //颜色数量
                num_count: num_count, //总数量
                unit: preViewOrder.sale_mode == 0?'条':'m', //单位
                list: Object.values(dataList)
            })
        }
    }

    const formatPreViewOrderMemo = useMemo(() => {
        return formatPreViewOrder
    }, [formatPreViewOrder])

    //复制功能
    const clipboardData = () => {
        Taro.setClipboardData({
            data: '123123121321',
            success: function (res) {
                Taro.showToast({
                    icon: 'none',
                    title: '复制成功'
                })
            }
        })
    }

    return (
        <View className={styles.order_main}>
            <OrderState state="预约中" desc="客服已接单，等待仓库配布出单..."/>
            <View className={styles.order_title}>
                <Text>收货方式</Text>
                <View className={styles.order_status}>物流</View>                
                <View className={styles.order_status}>上门自提</View>                
            </View>
            <AddressInfo/>
            <KindList value={formatPreViewOrderMemo}/>
            <View className={styles.order_desc} onClick={() => setShowDesc(true)}>
                <View className={styles.order_desc_con}>订单备注</View>
                <View className={styles.order_desc_text}>点击填写</View>
                <View className={classnames(styles.miconfont, 'iconfont icon-jiantou')}></View>
            </View>
            <View className={styles.order_info} >
                <View className={styles.order_info_title}>订单备注</View>
                <SearchInput showBorder={false} title='单号'>
                    <View className={styles.order_num}>
                        <Text>13535359535</Text>
                        <View className={styles.order_num_btn} onClick={() => clipboardData()}>复制</View>
                    </View>
                </SearchInput>
                <SearchInput showBorder={false} title='下单时间'>
                    <Text>2022-4-5 10:11:55</Text>
                </SearchInput>
            </View>
            <View className={styles.submit_order}>
                <View className={styles.submit_order_number}>
                    <EstimatedAmount style={{color:'#007AFF'}} number={formatPriceDiv(formatPreViewOrder?.estimate_amount)}/>    
                    <View className={styles.order_number_desc}>{`${formatPreViewOrder?.list.length}种面料，${formatPreViewOrder?.colo_count}种颜色，共${formatPreViewOrder?.num_count + formatPreViewOrder?.unit}`}</View>
                </View>
                <View className={styles.order_btn}>提交订单</View>    
            </View>        
            <Popup show={showDesc} showTitle={false} onClose={() => setShowDesc(false)} >
                <Remark onSave={(e) => console.log(e)}/>
            </Popup>
            <View className="common_safe_area_y"></View>
        </View>
    )
 }
